@@ -25,7 +25,8 @@ UBUNTU_RELEASES = (
     'cosmic',
     'disco',
     'eoan',
-    'focal'
+    'focal',
+    'groovy'
 )
 
 
